"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReactHoverImageFilter = void 0;
const react_1 = __importStar(require("react"));
const react_device_detect_1 = require("react-device-detect");
const converFromFilterToFilterOnEvent_1 = require("../helpers/converFromFilterToFilterOnEvent");
const useHoldPress_1 = require("../hooks/useHoldPress");
// component description: a simple canvas component that allows you to simulate paint effect with a mouse or finger simulating a paint brush applying a filter to the image on the coordinates of the mouse or finger position
// dont allow children to be passed to this component as it will break the canvas element
function ReactHoverImageFilter({ pixelPaintedSize, imageSrc, canvasStyle, paintEvent, width, height, fromFilter = 'grayscale(100%)', toFilter = 'grayscale(0%)' }) {
    // pixelatedEffectSize
    // create a ref to store the canvas DOM element
    const canvasRef = (0, react_1.useRef)(null);
    const { isPaintingRef, handlers } = (0, useHoldPress_1.useHoldPress)();
    (0, react_1.useEffect)(() => {
        const image = new Image();
        image.src = imageSrc;
        image.crossOrigin = 'anonymous';
        image.addEventListener('load', () => {
            const canvas = canvasRef.current;
            const newCanvas = document.createElement('canvas');
            if (!canvas || !newCanvas)
                return;
            const ctx = canvas.getContext('2d', { willReadFrequently: true });
            const newCtx = newCanvas.getContext('2d', { willReadFrequently: true });
            newCanvas.width = width;
            newCanvas.height = height;
            if (!ctx || !newCtx)
                return;
            ctx.filter = fromFilter;
            newCtx.filter = toFilter;
            ctx.drawImage(image, 0, 0, canvas.width, canvas.height);
            // if (pixelatedEffectSize && pixelatedEffectSize > 0)
            //   pixelate(pixelatedEffectSize, ctx, canvas.width, canvas.height)
            newCtx.drawImage(image, 0, 0, canvas.width, canvas.height);
            const fromPixels = ctx.getImageData(0, 0, newCanvas.width, newCanvas.height);
            const toPixels = newCtx.getImageData(0, 0, canvas.width, canvas.height);
            canvas.addEventListener(react_device_detect_1.isBrowser ? 'mousemove' : 'touchmove', event => {
                if (isPaintingRef.current || paintEvent !== 'holdclick' || react_device_detect_1.isMobile) {
                    (0, converFromFilterToFilterOnEvent_1.converFromFilterToFilterOnEvent)(fromPixels, toPixels, event, ctx, pixelPaintedSize);
                }
            });
        });
        return () => {
            const canvas = canvasRef.current;
            if (!canvas)
                return;
            canvas.removeEventListener('mousemove', () => {
                return;
            });
            image.removeEventListener('load', () => {
                return;
            });
        };
    }, []);
    return (react_1.default.createElement("canvas", Object.assign({}, handlers, { ref: canvasRef, width: width, height: height, style: Object.assign({}, canvasStyle) })));
}
exports.ReactHoverImageFilter = ReactHoverImageFilter;
exports.default = ReactHoverImageFilter;
//# sourceMappingURL=ReactHoverImageFilter.js.map